@@ -6,5 +6,5 @@ Copyright:
 Please see LICENSE and AUTHORS for more information.
 """
 
-from models import ImmutableModel, CantDeleteImmutableException
+from models import ImmutableModel, CantDeleteImmutableException, PK_FIELD, UNDEFINED
 from admin import ImmutableModelAdmin
